//***************************************************************************//
//* FRIDA: flexible rapid interactive data analysis                         *//
//* (C) Joachim Wuttke 1990-, v2(C++) 2001-                                 *//
//* http://apps.jcns.fz-juelich.de/frida                                    *//
//***************************************************************************//

//! \file  var.h
//! \brief variable reference CVar

//! Variable type (and number, if applicable).

class CVar {
    // Variables may be unnumbered (x,y,i,j,k,c,...) or numbered (z0,p0,r0)
 public:
    enum TTyp {
        _NOREF=0,
        _X, _Y, _Z, _R, // data
        _DY,            // associated error
        _C, _CP, _CQ,   // curve, curve parameters, curve quality
        _K, _J, _I,     // indices for file, spectrum, point   
        _NJ, _NI        // number of spectra in file, points in spectrum
    };
    TTyp typ;
    uint num;

    CVar( TTyp _typ=_NOREF, uint _num=0 ) : typ(_typ), num(_num) {};
    CVar( const string s );

    bool is_errvar() const {
        return typ==_DY; }
    bool pointwise() const { 
        return typ==_X || typ==_Y || typ==_DY || typ==_I; };
    bool numbered() const {
        return typ==_CP || typ==_CQ || typ==_Z; };

    CVar errvar() const;

    string var_info() const;

 private:
    int requestNum( string s, int pos );
};
